pub enum LogMessage {
Start {
evobench_log_version: u32,
evobench_version: KString,
},
Metadata(Metadata),
KeyValue(KeyValue),
TStart(Timing),
T(Timing),
TS(Timing),
TE(Timing),
TThreadStart(Timing),
TThreadEnd(Timing),
TEnd(Timing),
TIO(Timing),
}Variants
Start
Start describes the file format. Do not change this ennum
item! This is separate from Metadata so that Metadata can
be changed; Start must not change so that the parser can
detect the version then switch to the right parser for the
rest.
Metadata(Metadata)
Random information from the program.
KeyValue(KeyValue)
Random information from the program.
TStart(Timing)
For the other items, see the doc comments in hpp file
T(Timing)
TS(Timing)
TE(Timing)
TThreadStart(Timing)
TThreadEnd(Timing)
TEnd(Timing)
TIO(Timing)
Implementations
Sourceimpl LogMessage
impl LogMessage
pub fn opt_data_message(&self) -> Option<DataMessage<'_>>
Sourcepub fn data_message(&self) -> DataMessage<'_>
pub fn data_message(&self) -> DataMessage<'_>
Note: panics for Start and Metadata messages, because those
are not in LogData::messages any more (XX type safe?). Use
opt_data_message() instead if not accessing those.